@@ -8,6 +8,7 @@ use Config::General;
 use Digest::SHA;
 use Env;
 use FileHandle;
+use Log::Log4perl;
 use parent;
 use POSIX;
 use Sys::Syslog;
@@ -21,6 +22,7 @@ print "Config::General ($Config::General::VERSION)\n";
 print "Digest::SHA ($Digest::SHA::VERSION)\n";
 print "Env ($Env::VERSION)\n";
 print "FileHandle ($FileHandle::VERSION)\n";
+print "Log::Log4perl ($Log::Log4perl::VERSION)\n";
 print "parent ($parent::VERSION)\n";
 print "POSIX ($POSIX::VERSION)\n";
 print "Sys::Syslog ($Sys::Syslog::VERSION)\n";
